==> pretur.sequelize-0.2.8.tgz: package/lib/resolver.js <==
"use strict";
var intersection = require('lodash/intersection');
function buildCustomResolver(spec, resolver) {
    var pool = null;
    function wrappedResolver(query) {
        return resolver(query, pool);
    }
    function initialize(p) {
        pool = p;
    }
    return { resolver: wrappedResolver, initialize: initialize };
}
exports.buildCustomResolver = buildCustomResolver;
function buildResolver(spec, options) {
    var pool = null;
    function resolver(rawQuery) {
        var query = rawQuery;
        if (options && typeof options.queryTransformer === 'function') {
            query = options.queryTransformer(rawQuery);
        }
        var Model = pool.models[spec.name].sequelizeModel;
        var findOptions = {};
        var attributes = pool.models[spec.name].sanitizeAttributes(query && query.attributes);
        if (attributes) {
            findOptions.attributes = attributes;
        }
        var include = buildInclude(query, pool, spec.name);
        if (include && include.length > 0) {
            findOptions.include = include;
        }
        if (query && (typeof query.byId === 'number' || typeof query.byId === 'string')) {
            var promise_1 = Model.findById(query.byId, findOptions).then(function (data) { return ({ data: [data] }); });
            if (options && options.intercept) {
                return promise_1.then(function (r) { return options.intercept(query, r); });
            }
            return promise_1;
        }
        var order = buildOrder(query, pool, spec.name);
        if (order) {
            findOptions.order = order;
        }
        var where = buildWhere(query, pool, spec.name);
        if (where) {
            findOptions.where = where;
        }
        var offset = query && query.pagination && query.pagination.skip;
        if (offset) {
            findOptions.offset = offset;
        }
        var limit = query && query.pagination && query.pagination.take;
        if (limit) {
            findOptions.limit = limit;
        }
        if (query && query.count) {
            var promise_2 = Model.findAndCount(findOptions).then(function (_a) {
                var rows = _a.rows, count = _a.count;
                return ({ count: count, data: rows });
            });
            if (options && options.intercept) {
                return promise_2.then(function (r) { return options.intercept(query, r); });
            }
            return promise_2;
        }
        var promise = Model.findAll(findOptions).then(function (data) { return ({ data: data }); });
        if (options && options.intercept) {
            return promise.then(function (r) { return options.intercept(query, r); });
        }
        return promise;
    }
    function initialize(p) {
        pool = p;
    }
    return { resolver: resolver, initialize: initialize };
}
exports.buildResolver = buildResolver;
function buildOrder(query, pool, model) {
    var defaultOrder = pool.models[model].defaultOrder;
    var parameters = [];
    if (query && query.order && query.order.field && query.order.ordering !== 'NONE') {
        if (Array.isArray(query.order.chain)) {
            var currentModel_1 = model;
            query.order.chain.forEach(function (alias) {
                var nextModel = pool.models[currentModel_1].aliasModelMap[alias];
                parameters.push({ model: pool.models[nextModel].sequelizeModel, as: alias });
                currentModel_1 = nextModel;
            });
        }
        parameters.push(query.order.field);
        parameters.push(query.order.ordering);
    }
    if (parameters.length === 0) {
        if (!Array.isArray(defaultOrder)) {
            return null;
        }
        return [defaultOrder.slice()];
    }
    return [parameters];
}
function buildWhere(query, pool, model) {
    var where = {};
    if (query && typeof query.filters === 'object' && query.filters !== null) {
        var filtersKeys = Object.keys(query.filters);
        if (pool.models[model].allowedAttributes) {
            filtersKeys = intersection(filtersKeys, pool.models[model].allowedAttributes);
        }
        filtersKeys.map(function (field) {
            var value = query.filters[field];
            if (pool.models[model].fieldWhereBuilders &&
                typeof pool.models[model].fieldWhereBuilders[field] === 'function') {
                where[field] = pool.models[model].fieldWhereBuilders[field](value);
            }
            else if (value === null) {
                where[field] = null;
            }
            else if (Array.isArray(value)) {
                where[field] = { $in: value };
            }
            else {
                switch (typeof value) {
                    case 'string':
                        where[field] = { $iLike: "%" + value + "%" };
                        break;
                    default:
                        where[field] = value;
                        break;
                }
            }
        });
        return where;
    }
    return null;
}
function buildInclude(query, pool, model) {
    var queryInclude = query && query.include;
    var orderChain = query && query.order && query.order.chain;
    return buildNestedInclude(pool, queryInclude, orderChain, model);
}
function buildNestedInclude(pool, queryInclude, orderChain, model) {
    var aliasModelMap = pool.models[model].aliasModelMap;
    var aliasRequiredMap = pool.models[model].aliasRequiredMap;
    if (queryInclude || orderChain) {
        var include_1 = [];
        Object.keys(aliasModelMap).forEach(function (alias) {
            if (queryInclude[alias] || (orderChain && orderChain[0] === alias)) {
                var subQuery = queryInclude[alias];
                var targetModel = pool.models[aliasModelMap[alias]];
                if (!targetModel.sequelizeModel) {
                    return;
                }
                var includedModel = {
                    model: targetModel.sequelizeModel,
                    as: alias,
                    required: aliasRequiredMap[alias],
                    attributes: targetModel.allowedAttributes
                };
                if (typeof subQuery === 'object' && subQuery) {
                    var attributes = targetModel.sanitizeAttributes(subQuery.attributes);
                    if (attributes) {
                        includedModel.attributes = attributes;
                    }
                    var where = buildWhere(subQuery, pool, aliasModelMap[alias]);
                    if (where) {
                        includedModel.where = where;
                    }
                }
                var nestedInclude = buildNestedInclude(pool, typeof subQuery === 'object' && subQuery.include, Array.isArray(orderChain) && orderChain.slice(1), aliasModelMap[alias]);
                if (nestedInclude) {
                    includedModel.include = nestedInclude;
                }
                include_1.push(includedModel);
            }
        });
        return include_1;
    }
    return null;
}

==> pretur.sequelize-0.3.2.tgz: package/lib/resolver.js <==
"use strict";
var lodash_1 = require('lodash');
function buildCustomResolver(_, resolver) {
    var pool = null;
    function wrappedResolver(query) {
        return resolver(query, pool);
    }
    function initialize(p) {
        pool = p;
    }
    return { resolver: wrappedResolver, initialize: initialize };
}
exports.buildCustomResolver = buildCustomResolver;
function buildResolver(spec, options) {
    var pool = null;
    function resolver(rawQuery) {
        var query = rawQuery;
        if (options && typeof options.queryTransformer === 'function') {
            query = options.queryTransformer(rawQuery);
        }
        var Model = pool.models[spec.name].sequelizeModel;
        var findOptions = {};
        var attributes = pool.models[spec.name].sanitizeAttributes(query && query.attributes);
        if (attributes) {
            findOptions.attributes = attributes;
        }
        var include = buildInclude(query, pool, spec.name);
        if (include && include.length > 0) {
            findOptions.include = include;
        }
        if (query && (typeof query.byId === 'number' || typeof query.byId === 'string')) {
            var promise_1 = Model.findById(query.byId, findOptions).then(function (data) { return ({ data: [data] }); });
            if (options && options.intercept) {
                return promise_1.then(function (r) { return options.intercept(query, r); });
            }
            return promise_1;
        }
        var order = buildOrder(query, pool, spec.name);
        if (order) {
            findOptions.order = order;
        }
        var where = buildWhere(query, pool, spec.name);
        if (where) {
            findOptions.where = where;
        }
        var offset = query && query.pagination && query.pagination.skip;
        if (offset) {
            findOptions.offset = offset;
        }
        var limit = query && query.pagination && query.pagination.take;
        if (limit) {
            findOptions.limit = limit;
        }
        if (query && query.count) {
            var promise_2 = Model.findAndCount(findOptions)
                .then(function (_a) {
                var rows = _a.rows, count = _a.count;
                return ({ count: count, data: rows });
            });
            if (options && options.intercept) {
                return promise_2.then(function (r) { return options.intercept(query, r); });
            }
            return promise_2;
        }
        var promise = Model.findAll(findOptions).then(function (data) { return ({ data: data }); });
        if (options && options.intercept) {
            return promise.then(function (r) { return options.intercept(query, r); });
        }
        return promise;
    }
    function initialize(p) {
        pool = p;
    }
    return { resolver: resolver, initialize: initialize };
}
exports.buildResolver = buildResolver;
function buildOrder(query, pool, model) {
    var defaultOrder = pool.models[model].defaultOrder;
    var parameters = [];
    if (query && query.order && query.order.field && query.order.ordering !== 'NONE') {
        if (Array.isArray(query.order.chain)) {
            var currentModel_1 = model;
            query.order.chain.forEach(function (alias) {
                var nextModel = pool.models[currentModel_1].aliasModelMap[alias];
                parameters.push({ as: alias, model: pool.models[nextModel].sequelizeModel });
                currentModel_1 = nextModel;
            });
        }
        parameters.push(query.order.field);
        parameters.push(query.order.ordering);
    }
    if (parameters.length === 0) {
        if (!Array.isArray(defaultOrder)) {
            return null;
        }
        return [defaultOrder.slice()];
    }
    return [parameters];
}
function buildWhere(query, pool, model) {
    var where = {};
    if (query && typeof query.filters === 'object' && query.filters !== null) {
        var filtersKeys = Object.keys(query.filters);
        if (pool.models[model].allowedAttributes) {
            filtersKeys = lodash_1.intersection(filtersKeys, pool.models[model].allowedAttributes);
        }
        filtersKeys.map(function (field) {
            var value = query.filters[field];
            if (pool.models[model].fieldWhereBuilders &&
                typeof pool.models[model].fieldWhereBuilders[field] === 'function') {
                where[field] = pool.models[model].fieldWhereBuilders[field](value);
            }
            else if (value === null) {
                where[field] = null;
            }
            else if (Array.isArray(value)) {
                where[field] = { $in: value };
            }
            else {
                switch (typeof value) {
                    case 'string':
                        where[field] = { $iLike: "%" + value + "%" };
                        break;
                    default:
                        where[field] = value;
                        break;
                }
            }
        });
        return where;
    }
    return null;
}
function buildInclude(query, pool, model) {
    var queryInclude = query && query.include;
    var orderChain = query && query.order && query.order.chain;
    return buildNestedInclude(pool, queryInclude, orderChain, model);
}
function buildNestedInclude(pool, queryInclude, orderChain, model) {
    var aliasModelMap = pool.models[model].aliasModelMap;
    var aliasRequiredMap = pool.models[model].aliasRequiredMap;
    if (queryInclude || orderChain) {
        var include_1 = [];
        Object.keys(aliasModelMap).forEach(function (alias) {
            if (queryInclude[alias] || (orderChain && orderChain[0] === alias)) {
                var subQuery = queryInclude[alias];
                var targetModel = pool.models[aliasModelMap[alias]];
                if (!targetModel.sequelizeModel) {
                    return;
                }
                var includedModel = {
                    as: alias,
                    attributes: targetModel.allowedAttributes,
                    model: targetModel.sequelizeModel,
                    required: aliasRequiredMap[alias],
                };
                if (typeof subQuery === 'object' && subQuery) {
                    var attributes = targetModel.sanitizeAttributes(subQuery.attributes);
                    if (attributes) {
                        includedModel.attributes = attributes;
                    }
                    var where = buildWhere(subQuery, pool, aliasModelMap[alias]);
                    if (where) {
                        includedModel.where = where;
                    }
                }
                var nestedInclude = buildNestedInclude(pool, (typeof subQuery === 'object' && subQuery.include) || undefined, (Array.isArray(orderChain) && orderChain.slice(1)) || undefined, aliasModelMap[alias]);
                if (nestedInclude) {
                    includedModel.include = nestedInclude;
                }
                include_1.push(includedModel);
            }
        });
        return include_1;
    }
    return null;
}
